from dataclasses import dataclass
import numpy as np

from abc import abstractmethod

from agogos._core.block import Block


@dataclass
class Refiner(Block):

    @abstractmethod
    def predict(self, predictions: np.ndarray) -> np.ndarray:
        """Predict the target variable.
        
        :param predictions: The predictions to refine.
        :return: The predictions."""
        pass


from agogos.refiner import Refiner
import pytest

class TestRefiner:

    def test_refine(self):
        
        class refinerInstance(Refiner):
            def predict(self, predictions):
                return predictions
            
        refiner = refinerInstance()

        assert refiner.predict([1, 2, 3]) == [1, 2, 3]

    def test_refine_abstract(self):
        with pytest.raises(TypeError):
            Refiner()


"""The block module contains the Block class."""
from dataclasses import dataclass
from joblib import hash


@dataclass
class Block:
    """A block in the machine learning pipeline."""

    def __post_init__(self) -> None:
        """Initialize the block."""
        self._set_hash('')

    def _set_hash(self, prev_hash: str) -> None:
        """Set the hash of the block.
        
        :param prev_hash: The hash of the previous block.
        """
        self._hash = hash(prev_hash + str(self))

    def get_hash(self) -> str:
        """Get the hash of the block.
        
        :return: The hash of the block.
        """
        return self._hash

    